@@ -15,13 +15,12 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
-*/  
-
-#include <setjmp.h>
+*/
 
+#include "jerror.h"
 #include "jinclude.h"
 #include "jpeglib.h"
-#include "jerror.h"
+#include <csetjmp>
 
 // Stop complaints about deuplicate definitions
 #undef HAVE_STDLIB_H
