@@ -462,11 +462,9 @@ VideoStream::VideoStream( const char *in_filename, const char *in_format, int bi
 	SetParameters( );
     
   // Allocate buffered packets.
-  packet_buffers = new AVPacket*[2];
-  packet_buffers[0] = new AVPacket();
-  packet_buffers[1] = new AVPacket();
-  packet_index = 0;
-	
+  for (auto &pkt : packet_buffers)
+    pkt = av_packet_ptr{av_packet_alloc()};
+
 	// Initialize mutex used by streaming thread.
 	if ( pthread_mutex_init( buffer_copy_lock, nullptr ) != 0 ) {
 		Fatal("pthread_mutex_init failed");
@@ -498,16 +496,13 @@ VideoStream::~VideoStream( ) {
 		}
 		delete buffer_copy_lock;
 	}
-    
-  if (packet_buffers) {
-    delete packet_buffers[0];
-    delete packet_buffers[1];
-    delete[] packet_buffers;
-  }
-	
 	/* close each codec */
 	if ( ost ) {
+#if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
+		avcodec_free_context ( &codec_context );
+#else
 		avcodec_close( codec_context );
+#endif
 		av_free( opicture->data[0] );
 		av_frame_free( &opicture );
 		if ( tmp_opicture ) {
@@ -608,9 +603,7 @@ double VideoStream::ActuallyEncodeFrame( const uint8_t *buffer, int buffer_size,
 		memcpy( opicture->data[0], buffer, buffer_size );
 	}
 	AVFrame *opicture_ptr = opicture;
-	
-	AVPacket *pkt = packet_buffers[packet_index];
-	av_init_packet( pkt );
+	AVPacket *pkt = packet_buffers[packet_index].get();
   int got_packet = 0;
 #if LIBAVFORMAT_VERSION_CHECK(57, 0, 0, 0, 0)
     if (codec_context->codec_type == AVMEDIA_TYPE_VIDEO &&
@@ -628,9 +621,13 @@ double VideoStream::ActuallyEncodeFrame( const uint8_t *buffer, int buffer_size,
 		pkt->data = (uint8_t *)opicture_ptr;
     pkt->size = buffer_size;
     got_packet = 1;
-	} else {
-		opicture_ptr->pts = codec_context->frame_number;
-		opicture_ptr->quality = codec_context->global_quality;
+  } else {
+#if LIBAVCODEC_VERSION_CHECK(60, 2, 0, 2, 100)
+    opicture_ptr->pts = codec_context->frame_num;
+#else
+    opicture_ptr->pts = codec_context->frame_number;
+#endif
+    opicture_ptr->quality = codec_context->global_quality;
 
 #if LIBAVCODEC_VERSION_CHECK(57, 64, 0, 64, 0)
       avcodec_send_frame(codec_context, opicture_ptr);
@@ -730,7 +727,7 @@ void *VideoStream::StreamingThreadCallback(void *ctx){
     // Since this lag is not constant the client may skip frames.
 
     // Get the last rendered packet.
-    AVPacket *packet = videoStream->packet_buffers[videoStream->packet_index];
+    AVPacket *packet = videoStream->packet_buffers[videoStream->packet_index].get();
     if (packet->size) {
       videoStream->SendPacket(packet);
     }
