@@ -165,6 +165,7 @@ $SLANG = array(
     'BadPort'               => 'Port must be set to a valid number',
     'BadPostEventCount'     => 'Post event image count must be an integer of zero or more',
     'BadPreEventCount'      => 'Pre event image count must be at least zero, and less than image buffer size',
+    'BadPreEventCountMaxImageBufferCount'      => 'Max Image Buffer Count should be greater than Pre event image count or else it cannot be satisfied',
     'BadRefBlendPerc'       => 'Reference blend percentage must be a positive integer',
     'BadNoSaveJPEGsOrVideoWriter' => 'SaveJPEGs and VideoWriter are both set to disabled.  Nothing will be recorded!',
     'BadSectionLength'      => 'Section length must be an integer of 30 or more',
@@ -272,10 +273,10 @@ $SLANG = array(
     'Debug'                 => 'Debug',
     'DefaultRate'           => 'Default Rate',
     'DefaultScale'          => 'Default Scale',
-    'DefaultCodec'          => 'Default Method For Live View',
+    'DefaultCodec'          => 'Default Method For Viewing Events',
     'DefaultView'           => 'Default View',
     'Deinterlacing'         => 'Deinterlacing',
-    'RTSPDescribe'         => 'Use RTSP Response Media URL',
+    'RTSPDescribe'          => 'Use RTSP Response Media URL',
     'Delay'                 => 'Delay',
     'DeleteAndNext'         => 'Delete &amp; Next',
     'DeleteAndPrev'         => 'Delete &amp; Prev',
@@ -1051,6 +1052,15 @@ $OLANG = array(
       Some, mostly older, IP cameras support snapshot mode. In this case ZoneMinder is actively polling the camera
       for new images. In this case, it is safe to use the field.
       '
+	),
+	'OPTIONS_ALARMMAXFPS' => array(
+    'Help' => '
+    This field has certain limitations when used for non-local devices.~~
+    Failure to adhere to these limitations will cause a delay in live video, irregular frame skipping,
+    and missed events~
+    This setting allows you to override the Maximum FPS value if this circumstance occurs. As with the Maximum FPS 
+    setting, leaving this blank implies no limit.
+    '
 	),
 	'OPTIONS_LINKED_MONITORS' => array(
     'Help' => '
