@@ -37,8 +37,7 @@ $rates = array(
 );
 
 $scales = array(
-    '0' => translate('Scale to Fit'),
-    '' => translate('Fixed Width/Height'),
+    '0' => translate('Auto'),
     '400' => '4x',
     '300' => '3x',
     '200' => '2x',
@@ -54,7 +53,7 @@ $scales = array(
 if ( isset($_REQUEST['view']) && ($_REQUEST['view'] == 'montage') ) {
   unset($scales['auto']); //Remove auto on montage, use everywhere else
 } else {
-  unset($scales['']); //Remove fixed on everything but montage
+  unset($scales['fixed']); //Remove fixed on everything but montage
 }
 
 $bandwidth_options = array(
