@@ -1,9 +1,10 @@
 function submitCamera( element ) {
   var form = element.form;
-  form.target = opener.name;
+  if (opener) {
+    form.target = opener.name;
+  }
   form.view.value = 'monitor';
   form.submit();
-  closeWindow.delay( 250 );
 }
 
 function configureButtons( element ) {
