@@ -7,12 +7,12 @@ function AddNewZone(el) {
 var monitors = new Array();
 
 function initPage() {
-  for ( var i = 0, length = monitorData.length; i < length; i++ ) {
+  for ( let i = 0, length = monitorData.length; i < length; i++ ) {
     monitors[i] = new MonitorStream(monitorData[i]);
 
     // Start the fps and status updates. give a random delay so that we don't assault the server
-    var delay = Math.round( (Math.random()+0.5)*statusRefreshTimeout );
-    monitors[i].setStreamScale('0');
+    const delay = Math.round( (Math.random()+0.5)*statusRefreshTimeout );
+    monitors[i].setScale('0');
     monitors[i].start(delay);
   }
 
@@ -40,4 +40,3 @@ function streamCmdQuit() {
 }
 
 window.addEventListener('DOMContentLoaded', initPage);
-
